Module bus

Module bus 

Structs

CommandBus
MPSC command bus for dispatching user actions to the presentation engine.
CommandReceiver
Receiving end of the command bus, held by the engine.
CommandSender
Cloneable handle for sending commands into the bus.