pub struct KeybindingMap { /* private fields */ }Expand description
Maps key combinations to actions.
Implementations
Sourceimpl KeybindingMap
impl KeybindingMap
Sourcepub fn from_config(user_bindings: &HashMap<String, Vec<String>>) -> Self
pub fn from_config(user_bindings: &HashMap<String, Vec<String>>) -> Self
Build a keybinding map from user config overlaid on defaults.
Sourcepub fn from_full_config(config: &Config) -> Self
pub fn from_full_config(config: &Config) -> Self
Build a keybinding map from config plus the active clicker profile.