Module bus
dais_
core
0.1.0
Module bus
Module Items
Structs
In crate dais_
core
dais_core
Module
bus
Structs

Command
Bus
MPSC command bus for dispatching user actions to the presentation engine.
Command
Receiver
Receiving end of the command bus, held by the engine.
Command
Sender
Cloneable handle for sending commands into the bus.