Module state

Module state 

Structs

ActivePen
The currently selected pen settings used to initialise the next stroke.
InkStroke
A single ink stroke drawn on a slide.
PointerAppearance
Color and size for one pointer visual style.
PointerAppearances
Per-style pointer appearance settings.
PresentationState
The single authoritative state of the presentation.
TextBox
A positioned text overlay on a slide.
TimerState
Timer state for the presentation.
ZoomRegion
Defines a zoom region on the slide.

Enums

PointerStyle
Visual style for the audience laser pointer.
TimerMode
Timer counting mode.
TimerPhase
Visual phase of the timer, derived from state each frame.